@@ -1,36 +1,30 @@
-#' Age based data
+#' Get Age-Based Data
 #'
-#' Returns age-based information such as sex, maturity, and age counts per length of sampled species.
+#' Get age-based data such as sex, maturity, and age counts per length of sampled species.
 #'
-#' @param survey the survey accronym e.g. NS-IBTS, BITS.
-#' @param year the numeric year of the survey, e.g. 2010.
+#' @param survey the survey acronym, e.g. NS-IBTS.
+#' @param year the year of the survey, e.g. 2010.
 #' @param quarter the quarter of the year the survey took place, i.e. 1, 2, 3 or 4.
 #'
-#'
-#' @return A data.frame.
+#' @return A data frame.
 #'
 #' @seealso
-#' \code{\link{getSurveyList}} returns the acronyms for available surveys.
+#' \code{\link{getDATRAS}} supports querying many years and quarters in one function call.
 #'
-#' \code{\link{getSurveyYearList}} returns the years available for a given survey.
-#'
-#' \code{\link{getSurveyYearQuarterList}} returns the quarters available for a given survey and year.
+#' \code{\link{getHHdata}} and \code{\link{getHLdata}} get haul data and
+#' length-based data.
 #'
 #' \code{\link{icesDatras-package}} gives an overview of the package.
 #'
 #' @author Colin Millar.
 #'
 #' @examples
-#' # read age data
-#' cadata <- getCAdata(survey = "BTS", year = 2015, quarter = 3)
+#' cadata <- getCAdata(survey = "ROCKALL", year = 2002, quarter = 3)
 #' str(cadata)
 #'
-#'
 #' @export
 
 getCAdata <- function(survey, year, quarter) {
-  # Returns age-based information such as sex, maturity, and age counts per length of sampled species.
-
   # check survey name
   if (!checkSurveyOK(survey)) return(FALSE)
 
@@ -40,16 +34,13 @@ getCAdata <- function(survey, year, quarter) {
   # check quarter
   if (!checkSurveyYearQuarterOK(survey, year, quarter, checksurvey = FALSE, checkyear = FALSE)) return(FALSE)
 
-  # read and parse XML from api
+  # read url and parse to data frame
   url <-
     sprintf(
       "https://datras.ices.dk/WebServices/DATRASWebService.asmx/getCAdata?survey=%s&year=%i&quarter=%i",
       survey, year, quarter)
-  out <- curlDatras(url = url)
+  out <- readDatras(url)
   out <- parseDatras(out)
 
-  # return
   out
 }
-
-
